# © A line with UTF-8 produces
# UnicodeDecodeError: 'ascii' codec can't decode byte
# if not properly handled


def hello_world():
    print("hello world")  # noqa: T201
